# NequIP Developers

Present and past contributors include, in alphabetical order by last name:

 - [Simon Batzner](https://simonbatzner.github.io/)
 - [Marc Descoteaux](https://www.marcdescoteaux.com/)
 - [Mario Geiger](https://mariogeiger.ch/)
 - Y. Richard Hu
 - Anders Johansson
 - [Seán Kavanagh](https://seankavanagh.com/)
 - [Mit Kotak](https://mitkotak.github.io/)
 - [Prof. Boris Kozinsky](https://mir.g.harvard.edu/)
 - Albert Musaelian
 - Gabriel de Miranda Nascimento
 - Aadit Saluja
 - [Prof. Tess Smidt](https://blondegeek.github.io/)
 - Lixin Sun
 - [Chuin Wei Tan](https://cw-tan.github.io/)
 - Menghang (David) Wang
 - William C. Witt
 - Albert Zhu
 - Laura Zichi